@@ -1,9 +1,11 @@
 # $Header: /home/jesse/DBIx-SearchBuilder/history/SearchBuilder/Handle.pm,v 1.21 2002/01/28 06:11:37 jesse Exp $
 package DBIx::SearchBuilder::Handle;
+use strict;
 use Carp;
 use DBI;
-use strict;
 use Class::ReturnValue;
+use Encode;
+
 use vars qw($VERSION @ISA %DBIHandle $PrevHandle $DEBUG $TRANSDEPTH);
 
 $TRANSDEPTH = 0;
@@ -341,7 +343,7 @@ sub Insert {
   }
 
   my $QueryString =
-    "INSERT INTO $table (". join(", ", @cols). ") VALUES ".
+    "INSERT INTO $table (". join(", ", map {$self->dbh->quote_identifier($_) } @cols). ") VALUES ".
     "(". join(", ", @vals). ")";
 
     my $sth =  $self->SimpleQuery($QueryString, @bind);
@@ -372,8 +374,8 @@ sub UpdateRecordValue {
                  @_ );
 
     my @bind  = ();
-    my $query = 'UPDATE ' . $args{'Table'} . ' ';
-     $query .= 'SET '    . $args{'Column'} . '=';
+    my $query = 'UPDATE ' . $self->dbh->quote_identifier($args{'Table'}) . ' ';
+     $query .= 'SET '    . $self->dbh->quote_identifier($args{'Column'}) . '=';
 
   ## Look and see if the field is being updated via a SQL function. 
   if ($args{'IsSQLFunction'}) {
@@ -387,7 +389,7 @@ sub UpdateRecordValue {
   ## Constructs the where clause.
   my $where  = 'WHERE ';
   foreach my $key (keys %{$args{'PrimaryKeys'}}) {
-     $where .= $key . "=?" . " AND ";
+     $where .= $self->dbh->quote_identifier($key) . "=?" . " AND ";
      push (@bind, $args{'PrimaryKeys'}{$key});
   }
      $where =~ s/AND\s$//;
